0.4
---
- Define Upload.save, Upload.save_from, Upload.load
- Replace get_upload_from with Upload.get_from

0.3
---
- Handle HTTP status code 413 Payload Too Large

0.2
---
- Ignore multiple clicks on upload button until dialog closes
- Replace uploaded.ir.upload with uploaded.ir

0.1
---
- Add basic upload functionality
- Ignore multiple clicks on upload button for a few seconds
